# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Callable, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'MappingMapping',
]

@pulumi.output_type
class MappingMapping(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "pushStatus":
            suggest = "push_status"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in MappingMapping. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        MappingMapping.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        MappingMapping.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 expression: str,
                 id: str,
                 push_status: Optional[str] = None):
        """
        :param str id: The mapping property key.
        """
        MappingMapping._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            expression=expression,
            id=id,
            push_status=push_status,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             expression: str,
             id: str,
             push_status: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions]=None,
             **kwargs):
        if 'pushStatus' in kwargs:
            push_status = kwargs['pushStatus']

        _setter("expression", expression)
        _setter("id", id)
        if push_status is not None:
            _setter("push_status", push_status)

    @property
    @pulumi.getter
    def expression(self) -> str:
        return pulumi.get(self, "expression")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The mapping property key.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="pushStatus")
    def push_status(self) -> Optional[str]:
        return pulumi.get(self, "push_status")


