# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Callable, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetServerScopesScopeResult',
]

@pulumi.output_type
class GetServerScopesScopeResult(dict):
    def __init__(__self__, *,
                 consent: str,
                 default: bool,
                 description: str,
                 display_name: str,
                 id: str,
                 metadata_publish: str,
                 name: str,
                 optional: bool,
                 system: bool):
        GetServerScopesScopeResult._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            consent=consent,
            default=default,
            description=description,
            display_name=display_name,
            id=id,
            metadata_publish=metadata_publish,
            name=name,
            optional=optional,
            system=system,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             consent: str,
             default: bool,
             description: str,
             display_name: str,
             id: str,
             metadata_publish: str,
             name: str,
             optional: bool,
             system: bool,
             opts: Optional[pulumi.ResourceOptions]=None,
             **kwargs):
        if 'displayName' in kwargs:
            display_name = kwargs['displayName']
        if 'metadataPublish' in kwargs:
            metadata_publish = kwargs['metadataPublish']

        _setter("consent", consent)
        _setter("default", default)
        _setter("description", description)
        _setter("display_name", display_name)
        _setter("id", id)
        _setter("metadata_publish", metadata_publish)
        _setter("name", name)
        _setter("optional", optional)
        _setter("system", system)

    @property
    @pulumi.getter
    def consent(self) -> str:
        return pulumi.get(self, "consent")

    @property
    @pulumi.getter
    def default(self) -> bool:
        return pulumi.get(self, "default")

    @property
    @pulumi.getter
    def description(self) -> str:
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="metadataPublish")
    def metadata_publish(self) -> str:
        return pulumi.get(self, "metadata_publish")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def optional(self) -> bool:
        return pulumi.get(self, "optional")

    @property
    @pulumi.getter
    def system(self) -> bool:
        return pulumi.get(self, "system")


