# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Callable, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'RuleIdpDiscoveryAppExclude',
    'RuleIdpDiscoveryAppInclude',
    'RuleIdpDiscoveryPlatformInclude',
    'RuleIdpDiscoveryUserIdentifierPattern',
    'RuleMfaAppExclude',
    'RuleMfaAppInclude',
    'RuleSignonFactorSequence',
    'RuleSignonFactorSequenceSecondaryCriteria',
]

@pulumi.output_type
class RuleIdpDiscoveryAppExclude(dict):
    def __init__(__self__, *,
                 type: str,
                 id: Optional[str] = None,
                 name: Optional[str] = None):
        """
        :param str id: The ID of this resource.
        """
        RuleIdpDiscoveryAppExclude._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            type=type,
            id=id,
            name=name,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             type: str,
             id: Optional[str] = None,
             name: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions]=None,
             **kwargs):

        _setter("type", type)
        if id is not None:
            _setter("id", id)
        if name is not None:
            _setter("name", name)

    @property
    @pulumi.getter
    def type(self) -> str:
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def id(self) -> Optional[str]:
        """
        The ID of this resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        return pulumi.get(self, "name")


@pulumi.output_type
class RuleIdpDiscoveryAppInclude(dict):
    def __init__(__self__, *,
                 type: str,
                 id: Optional[str] = None,
                 name: Optional[str] = None):
        """
        :param str id: The ID of this resource.
        """
        RuleIdpDiscoveryAppInclude._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            type=type,
            id=id,
            name=name,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             type: str,
             id: Optional[str] = None,
             name: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions]=None,
             **kwargs):

        _setter("type", type)
        if id is not None:
            _setter("id", id)
        if name is not None:
            _setter("name", name)

    @property
    @pulumi.getter
    def type(self) -> str:
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def id(self) -> Optional[str]:
        """
        The ID of this resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        return pulumi.get(self, "name")


@pulumi.output_type
class RuleIdpDiscoveryPlatformInclude(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "osExpression":
            suggest = "os_expression"
        elif key == "osType":
            suggest = "os_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RuleIdpDiscoveryPlatformInclude. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RuleIdpDiscoveryPlatformInclude.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RuleIdpDiscoveryPlatformInclude.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 os_expression: Optional[str] = None,
                 os_type: Optional[str] = None,
                 type: Optional[str] = None):
        """
        :param str os_expression: Only available with OTHER OS type
        """
        RuleIdpDiscoveryPlatformInclude._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            os_expression=os_expression,
            os_type=os_type,
            type=type,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             os_expression: Optional[str] = None,
             os_type: Optional[str] = None,
             type: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions]=None,
             **kwargs):
        if 'osExpression' in kwargs:
            os_expression = kwargs['osExpression']
        if 'osType' in kwargs:
            os_type = kwargs['osType']

        if os_expression is not None:
            _setter("os_expression", os_expression)
        if os_type is not None:
            _setter("os_type", os_type)
        if type is not None:
            _setter("type", type)

    @property
    @pulumi.getter(name="osExpression")
    def os_expression(self) -> Optional[str]:
        """
        Only available with OTHER OS type
        """
        return pulumi.get(self, "os_expression")

    @property
    @pulumi.getter(name="osType")
    def os_type(self) -> Optional[str]:
        return pulumi.get(self, "os_type")

    @property
    @pulumi.getter
    def type(self) -> Optional[str]:
        return pulumi.get(self, "type")


@pulumi.output_type
class RuleIdpDiscoveryUserIdentifierPattern(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "matchType":
            suggest = "match_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RuleIdpDiscoveryUserIdentifierPattern. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RuleIdpDiscoveryUserIdentifierPattern.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RuleIdpDiscoveryUserIdentifierPattern.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 match_type: Optional[str] = None,
                 value: Optional[str] = None):
        RuleIdpDiscoveryUserIdentifierPattern._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            match_type=match_type,
            value=value,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             match_type: Optional[str] = None,
             value: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions]=None,
             **kwargs):
        if 'matchType' in kwargs:
            match_type = kwargs['matchType']

        if match_type is not None:
            _setter("match_type", match_type)
        if value is not None:
            _setter("value", value)

    @property
    @pulumi.getter(name="matchType")
    def match_type(self) -> Optional[str]:
        return pulumi.get(self, "match_type")

    @property
    @pulumi.getter
    def value(self) -> Optional[str]:
        return pulumi.get(self, "value")


@pulumi.output_type
class RuleMfaAppExclude(dict):
    def __init__(__self__, *,
                 type: str,
                 id: Optional[str] = None,
                 name: Optional[str] = None):
        """
        :param str id: The ID of this resource.
        """
        RuleMfaAppExclude._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            type=type,
            id=id,
            name=name,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             type: str,
             id: Optional[str] = None,
             name: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions]=None,
             **kwargs):

        _setter("type", type)
        if id is not None:
            _setter("id", id)
        if name is not None:
            _setter("name", name)

    @property
    @pulumi.getter
    def type(self) -> str:
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def id(self) -> Optional[str]:
        """
        The ID of this resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        return pulumi.get(self, "name")


@pulumi.output_type
class RuleMfaAppInclude(dict):
    def __init__(__self__, *,
                 type: str,
                 id: Optional[str] = None,
                 name: Optional[str] = None):
        """
        :param str id: The ID of this resource.
        """
        RuleMfaAppInclude._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            type=type,
            id=id,
            name=name,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             type: str,
             id: Optional[str] = None,
             name: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions]=None,
             **kwargs):

        _setter("type", type)
        if id is not None:
            _setter("id", id)
        if name is not None:
            _setter("name", name)

    @property
    @pulumi.getter
    def type(self) -> str:
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def id(self) -> Optional[str]:
        """
        The ID of this resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        return pulumi.get(self, "name")


@pulumi.output_type
class RuleSignonFactorSequence(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "primaryCriteriaFactorType":
            suggest = "primary_criteria_factor_type"
        elif key == "primaryCriteriaProvider":
            suggest = "primary_criteria_provider"
        elif key == "secondaryCriterias":
            suggest = "secondary_criterias"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RuleSignonFactorSequence. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RuleSignonFactorSequence.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RuleSignonFactorSequence.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 primary_criteria_factor_type: str,
                 primary_criteria_provider: str,
                 secondary_criterias: Optional[Sequence['outputs.RuleSignonFactorSequenceSecondaryCriteria']] = None):
        """
        :param str primary_criteria_factor_type: Type of a Factor
        :param str primary_criteria_provider: Factor provider
        """
        RuleSignonFactorSequence._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            primary_criteria_factor_type=primary_criteria_factor_type,
            primary_criteria_provider=primary_criteria_provider,
            secondary_criterias=secondary_criterias,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             primary_criteria_factor_type: str,
             primary_criteria_provider: str,
             secondary_criterias: Optional[Sequence['outputs.RuleSignonFactorSequenceSecondaryCriteria']] = None,
             opts: Optional[pulumi.ResourceOptions]=None,
             **kwargs):
        if 'primaryCriteriaFactorType' in kwargs:
            primary_criteria_factor_type = kwargs['primaryCriteriaFactorType']
        if 'primaryCriteriaProvider' in kwargs:
            primary_criteria_provider = kwargs['primaryCriteriaProvider']
        if 'secondaryCriterias' in kwargs:
            secondary_criterias = kwargs['secondaryCriterias']

        _setter("primary_criteria_factor_type", primary_criteria_factor_type)
        _setter("primary_criteria_provider", primary_criteria_provider)
        if secondary_criterias is not None:
            _setter("secondary_criterias", secondary_criterias)

    @property
    @pulumi.getter(name="primaryCriteriaFactorType")
    def primary_criteria_factor_type(self) -> str:
        """
        Type of a Factor
        """
        return pulumi.get(self, "primary_criteria_factor_type")

    @property
    @pulumi.getter(name="primaryCriteriaProvider")
    def primary_criteria_provider(self) -> str:
        """
        Factor provider
        """
        return pulumi.get(self, "primary_criteria_provider")

    @property
    @pulumi.getter(name="secondaryCriterias")
    def secondary_criterias(self) -> Optional[Sequence['outputs.RuleSignonFactorSequenceSecondaryCriteria']]:
        return pulumi.get(self, "secondary_criterias")


@pulumi.output_type
class RuleSignonFactorSequenceSecondaryCriteria(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "factorType":
            suggest = "factor_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RuleSignonFactorSequenceSecondaryCriteria. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RuleSignonFactorSequenceSecondaryCriteria.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RuleSignonFactorSequenceSecondaryCriteria.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 factor_type: str,
                 provider: str):
        """
        :param str factor_type: Type of a Factor
        :param str provider: Factor provider
        """
        RuleSignonFactorSequenceSecondaryCriteria._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            factor_type=factor_type,
            provider=provider,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             factor_type: str,
             provider: str,
             opts: Optional[pulumi.ResourceOptions]=None,
             **kwargs):
        if 'factorType' in kwargs:
            factor_type = kwargs['factorType']

        _setter("factor_type", factor_type)
        _setter("provider", provider)

    @property
    @pulumi.getter(name="factorType")
    def factor_type(self) -> str:
        """
        Type of a Factor
        """
        return pulumi.get(self, "factor_type")

    @property
    @pulumi.getter
    def provider(self) -> str:
        """
        Factor provider
        """
        return pulumi.get(self, "provider")


